# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class LocalFilesystemToS3Operator(BaseOperator):
    filename: "str"
    dest_key: "str"
    dest_bucket: "str | None"
    aws_conn_id: "str | None"
    verify: "str | bool | None"
    replace: "bool"
    encrypt: "bool"
    gzip: "bool"
    acl_policy: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToBigQueryOperator(BaseOperator):
    bucket: "_empty"
    source_objects: "_empty"
    destination_project_dataset_table: "_empty"
    schema_fields: "_empty"
    schema_object: "_empty"
    schema_object_bucket: "_empty"
    source_format: "_empty"
    compression: "_empty"
    create_disposition: "_empty"
    skip_leading_rows: "_empty"
    write_disposition: "_empty"
    field_delimiter: "_empty"
    max_bad_records: "_empty"
    quote_character: "_empty"
    ignore_unknown_values: "_empty"
    allow_quoted_newlines: "_empty"
    allow_jagged_rows: "_empty"
    encoding: "_empty"
    max_id_key: "_empty"
    gcp_conn_id: "_empty"
    schema_update_options: "_empty"
    src_fmt_configs: "_empty"
    external_table: "_empty"
    time_partitioning: "_empty"
    cluster_fields: "_empty"
    autodetect: "_empty"
    encryption_configuration: "_empty"
    location: "_empty"
    impersonation_chain: "str | Sequence[str] | None"
    labels: "_empty"
    description: "_empty"
    deferrable: "bool"
    result_retry: "Retry"
    result_timeout: "float | None"
    cancel_on_kill: "bool"
    job_id: "str | None"
    force_rerun: "bool"
    reattach_states: "set[str] | None"
    project_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class TimeDeltaSensor(BaseSensorOperator):
    delta: "_empty"


class TimeDeltaSensorAsync(TimeDeltaSensor):
    end_from_trigger: "bool"
    delta: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudBuildCancelBuildOperator(GoogleCloudBaseOperator):
    id_: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildCreateBuildOperator(GoogleCloudBaseOperator):
    build: "dict | Build"
    project_id: "str"
    wait: "bool"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    poll_interval: "float"
    deferrable: "bool"
    location: "str"


class CloudBuildCreateBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger: "dict | BuildTrigger"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildDeleteBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildGetBuildOperator(GoogleCloudBaseOperator):
    id_: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildGetBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildListBuildTriggersOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudBuildListBuildsOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    page_size: "int | None"
    filter_: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudBuildRetryBuildOperator(GoogleCloudBaseOperator):
    id_: "str"
    project_id: "str"
    wait: "bool"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildRunBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger_id: "str"
    source: "dict | RepoSource"
    project_id: "str"
    wait: "bool"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildUpdateBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger_id: "str"
    trigger: "dict | BuildTrigger"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class DmsTaskBaseSensor(AwsBaseSensor):
    replication_task_arn: "str"
    target_statuses: "Iterable[str] | None"
    termination_statuses: "Iterable[str] | None"


class DmsTaskCompletedSensor(DmsTaskBaseSensor):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AirbyteTriggerSyncOperator(BaseOperator):
    connection_id: "str"
    airbyte_conn_id: "str"
    asynchronous: "bool"
    deferrable: "bool"
    api_version: "str"
    api_type: "Literal['config', 'cloud']"
    wait_seconds: "float"
    timeout: "float"
